| RCNA_object-class | R Documentation |
An S4 class used to specify parameters for an analysis run
sample.namesRequired. Character vector containing names of subjects
ano.fileRequired. Character single file path detailing a feature-wise annotation file
out.dirRequired. Character vector containing the name of each subject?s output directory
gcParamsData Frame storing all run parameters for the correct_gc_bias function
nkrParamsData Frame storing all run parameters for the estimate_nkr function
scoreParamsData Frame storing all run parameters for the estimate_feature_score function
commandsRCNA_analysis object storing commands and parameters from previous function runs on this object
run_RCNA
RCNA_analysis,
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.