- obj
A RCNA_object type object - parameters will be pulled from the object instead, specifically from the `nkrParams` slot.
- ...
Additional arguments (unused)
- df
Path to the config file, or a `data.frame` object containing the valid parameters. Valid column names are `file.nkr.coverage`, `x.norm`, and `sample.names`. Additional columns will be ignored.
- sample.names
Character vector of sample names. Alternatively can be specified in `df`.
- ano.file
Location of the annotation file. This file must be in CSV format and contain the following information (with column headers as specified): "feature,chromosome,start,end".
- out.dir
Output directory for results. A subdirectory for results will be created under this + `/nkr/`.
- ncpus
Integer number of CPUs to use. Specifying more than one allows this function to be parallelized by feature.
- file.ci.coverage
Character vector listing the input coverage files. Must be the same length as `sample.names`. Alternatively can be specified in `df`.
- nkr
Numeric between 0 and 1 which specifies the coverage quantile that should be considered a "normal" karyotype range for each position. Lowering this value may increase sensitivity but also Type I error.
- x.norm
Whether or not to perform normalization for normal female/XX karyotype (default = FALSE). Can be specified for each sample separately via `df` column labeled `x.norm`.
- norm.cov.matrix
Character file path detailing the location of the normalized coverage matrix generated by this function. Re-using this file between runs can cut down on runtime significantly for large sample sizes. If the file doesn't exist yet it will be created at this location. If this file name ends in ".gz" then the output will be compressed using gzip.
- verbose
If set to TRUE will display more detail